@@ -35,7 +35,7 @@ set.seed(02138)
 ###################################################
 ### code chunk number 4: stmVignette.Rnw:230-231
 ###################################################
- load(url("http://goo.gl/7hyflA"))
+ load(url("http://goo.gl/91KbfS"))
 
 
 ###################################################
